# pppoe_manager.py
import netifaces
import json

class PPPoeManager:
    def __init__(self, file_path):
        self.file_path = file_path

    def read_pppoe_data(self):
        try:
            with open(self.file_path, 'r') as file:
                lines = file.readlines()
        except FileNotFoundError:
            print(f"拨号数据文件 '{self.file_path}' 未找到")
            return []

        pppoe_data = []
        ppp_interfaces = [interface for interface in netifaces.interfaces() if interface.startswith('ppp')]
        
        if not ppp_interfaces:
            print("未找到 PPP 接口")
            return []

        for line, ppp_interface in zip(lines, ppp_interfaces):
            try:
                # 只获取每行的前四个字段
                vlan_id, account, password, bind_adapter_name, *_ = line.strip().split()
                ip = netifaces.ifaddresses(ppp_interface)[netifaces.AF_INET][0]['addr']
                dial_data = {
                    "account": account,
                    "password": password,
                    "vlan_id": vlan_id,
                    "bind_adapter_name": bind_adapter_name,
                    "ip": ip,
                    "is_manage": 0,
                    "is_nat1": 1,
                    "adapter_name": ppp_interface,
                    "ipv6": ""
                }
                pppoe_data.append(dial_data)
            except KeyError:
                print(f"未能获取接口 {ppp_interface} 的 IP 地址")
            except ValueError:
                print(f"数据文件 '{self.file_path}' 格式错误: {line}")
            except Exception as e:
                print(f"处理接口 {ppp_interface} 时出错: {e}")

        return pppoe_data

    def get_pppoe_json(self):
        pppoe_data = self.read_pppoe_data()
        return json.dumps(pppoe_data, indent=4)